// #autoload
// #name = HalDeployer
// #version = 1.7
// #date = April 9, 2002
// #author = Halide
// #warrior = Halide
// #email = halide@tribes2.org
// #web = http://halides.tribes-univese.com/
// #description = Shows green/red indicator over reticle when you have a deployable, which lets you know if you can deploy at that location.
// #credit = PanamaJack - answered some questions
// #category = Halide's Scripts

if(!isObject(HalDeployer))
{
	new ScriptObject(HalDeployer)
	{
		class = HalDeployer;
		version = "1.7";
	};
}

function HalDeployerToggle(%val)
{
	if(!%val)
		return;

	$HalPref::Deployer::Enabled = !$HalPref::Deployer::Enabled;

	alxPlay(sButtonOver, 0, 0, 0);

	if($HalPref::Deployer::Enabled)
		addMessageHudLine("\c2HalDeployer enabled.");
	else
		addMessageHudLine("\c2HalDeployer disabled.");
}

function HalDeployerFailed(%msgType, %msgString, %errorSnd)
{
	HalDeployer.check();
}

function HalDeployerClearSensor()
{
	deploySensor.setVisible(false);
}

// START package HalDeployer
package HalDeployer
{

	function HalDeployer::setPrefs(%this)
	{
		if(isFile("prefs/HalPrefs.cs") && !$HalPrefsLoaded)
		{
			exec("prefs/HalPrefs.cs");
			$HalPrefsLoaded = true;
		}

		if($HalPref::Deployer::Version $= "")
		{
			$HalPref::Deployer::Version = HalDeployer.version;
			$HalPref::Deployer::Enabled = true;
		}
	}

	function clientCmdUpdatePackText(%num)
	{
		parent::clientCmdUpdatePackText(%num);

		if(!HalDeployer.inStation && %num > 0)
			HalDeployer.check();
	}

	function clientCmdSetBackpackHudItem(%num, %addItem)
	{
		parent::clientCmdSetBackpackHudItem(%num, %addItem);

		if($HalPref::Deployer::Enabled)
		{
			%pack = $BackpackHudData[%num, itemDataName];

			if(strStr(%pack, "Deployable") != -1 && %addItem > 0)
			{
				HalDeployer.hasDeployable = true;

				if(!HalDeployer.inStation)
					HalDeployer.start();
			}
			else
				HalDeployer.hasDeployable = false;
		}
	}

	function clientCmdSetDefaultVehicleKeys(%inVehicle)
	{
	   	parent::clientCmdSetDefaultVehicleKeys(%inVehicle);

		if(HalDeployer.hasDeployable)
		{
			if(%inVehicle)
				deploySensor.setVisible(false);
			else		
				HalDeployer.start();
		}
	}

	function clientCmdSetWeaponsHudClearAll()
	{
		parent::clientCmdSetWeaponsHudClearAll();
		
		if(HalDeployer.checkStation)
		{
			HalDeployer.inStation = true;

			deploySensor.setVisible(false);
		}
	}

	function clientCmdSetStationKeys(%inStation)
	{
		parent::clientCmdSetStationKeys(%inStation);

		HalDeployer.checkStation = %inStation;

		if(!HalDeployer.checkStation && HalDeployer.inStation)
		{
			HalDeployer.inStation = false;

			HalDeployer.check();
		}
	}

	function HalDeployer::start(%this)
	{
		if($HalPref::Deployer::Enabled)
		{
			useBackpack(true);
			deploySensor.setVisible(true);
		}
	}

	function HalDeployer::check(%this)
	{
		if(%this.hasDeployable)
			%this.start();
	}

	function OptionsDlg::onWake(%this)
	{
		if(!HalDeployer.bind)
		{
			$RemapName[$RemapCount] = "HalDeployer Toggle";
			$RemapCmd[$RemapCount] = "HalDeployerToggle";
			$RemapCount++;

			HalDeployer.bind = true;
		}

		parent::onWake(%this);
	}

	function DispatchLaunchMode()
	{
		parent::DispatchLaunchMode();

		HalDeployer.setPrefs();

		addMessageCallback('MsgGameOver', HalDeployerClearSensor);
		addMessageCallback('MsgDeployFailed', HalDeployerFailed);
	}

	function quit()
	{
		if(!$HalPrefsSaved)
		{
			export("$HalPref::*", "prefs/HalPrefs.cs", false);
			$HalPrefsSaved = true;
		}

		parent::quit();
	}

// END package HalDeployer
};
activatePackage(HalDeployer);